# Title: <descriptive title of the architecture concept>

- [Title: ](#title-)
- [Decision for Architecture Design](#decision-for-architecture-design)
  - [functional major decisions](#functional-major-decisions)
  - [non functional major decisions](#non-functional-major-decisions)
- [Component Diagram in plantuml](#component-diagram-in-plantuml)
- [Deployment diagram in plantuml](#deployment-diagram-in-plantuml)

# Decision for Architecture Design
## functional major decisions
<list of major functional decisions of the concept>

## non functional major decisions
<list of major non functional decisions of the concept>

# Component Diagram in plantuml
```

```
Description: <description of the purpose and the value of the components of the diagram>

# Deployment diagram in plantuml
```

```
Description: <description of the purpose and the value of the building blocks of the diagram>